@@ -149,14 +149,23 @@ def enable_python_hooks(ij):
                         print(str(view.msp.getAtlas().getName()))
                         if str(view.msp.getAtlas().getName()) == 'Adult Mouse Brain - Allen Brain Atlas V3p1':
                             print('Adult Mouse Brain - Allen Brain Atlas V3p1 detected, installing DeepSlice module')
+                            print('0')
                             BdvScijavaHelper = jimport('sc.fiji.bdvpg.scijava.BdvScijavaHelper')
+                            print('1')
                             from jpype import JImplements, JOverride
+                            print('2')
                             Runnable = jimport('java.lang.Runnable')
+                            print('3')
 
                             class DSPlaceHolder(object):
                                 def __init__(self, ij):
+                                    print('ze temp')
                                     self.temp_folder = prepare_deepslice_temp_folder(self)
+                                    print('alors')
                                     self.ij = ij
+                                    print('heu')
+
+                            print('4')
 
                             @JImplements(Runnable)
                             class ExecuteDeepSlicePython(object):
@@ -176,9 +185,19 @@ def enable_python_hooks(ij):
                                                               "dataset_folder", JString(self.dsp.temp_folder)
                                                               )
 
-                            BdvScijavaHelper.addActionToBdvHandleMenu(view.getBdvh(),
+                            print('5')
+                            print('ij= '+str(ij))
+                            dsplaceholder = DSPlaceHolder(ij)
+                            print('5A')
+                            edsp = ExecuteDeepSlicePython(dsplaceholder)
+                            print('5B')
+                            bdv_view = view.getBdvh()
+                            print('5C')
+
+                            BdvScijavaHelper.addActionToBdvHandleMenu(bdv_view,
                                                                       "Align>ABBA - DeepSlice Registration (Python)", 0,
-                                                                      ExecuteDeepSlicePython(DSPlaceHolder(ij)))
+                                                                      edsp)
+                            print('6')
 
     @JImplements(Supplier)
     class IPyWidgetCommandPreprocessorSupplier(object):
@@ -191,19 +210,24 @@ def enable_python_hooks(ij):
 
 
 def prepare_deepslice_temp_folder(self):
+    print('pdtf0')
     if not hasattr(self, '_run_deep_slice'):
         from src.abba_python.abba_private.DeepSliceProcessor import DeepSliceProcessor
         self._run_deep_slice = DeepSliceProcessor()
 
+    print('pdtf1')
     # TODO : fix potential multiple running instance issues
     temp_folder = tempfile.gettempdir() + '/temp/deepslice/'
 
+    print('pdtf2')
     # make sure that the folder exists
     if not os.path.exists(temp_folder):
         os.makedirs(temp_folder)
 
+    print('pdtf3')
     # clean folder : remove all previous files
     for filename in os.listdir(temp_folder):
+        print('pdtf3a')
         file_path = os.path.join(temp_folder, filename)
         try:
             if os.path.isfile(file_path) or os.path.islink(file_path):
@@ -211,7 +235,9 @@ def prepare_deepslice_temp_folder(self):
             # elif os.path.isdir(file_path):
             #    shutil.rmtree(file_path)
         except Exception as e:
+            print('pdtf3error')
             print('Failed to delete %s. Reason: %s' % (file_path, e))
+    print('pdtf4')
     # print('Temp folder = '+str(temp_folder))
     return temp_folder
 
